pub struct CheckpointCheckView<'view, 'target, 'tcx> {
pub checkpoint_index: usize,
pub checkpoint: &'view Checkpoint<'tcx>,
pub tree: &'view PathTree,
pub properties: &'target [Property<'tcx>],
}Expand description
Returns whether a function returns the owning struct type (i.e. is a constructor). Borrowed view of all verification inputs for one unsafe checkpoint.
Fields
checkpoint_index: usizePosition among checkpoints that have properties to verify.
checkpoint: &'view Checkpoint<'tcx>The concrete unsafe checkpoint in the caller MIR body.
tree: &'view PathTreePer-checkpoint prefix tree of all verification paths to this checkpoint.
properties: &'target [Property<'tcx>]Required safety properties for the unsafe callee.